==> fabric-loom-native-0.1.0-sources.jar: net/fabricmc/loom/nativeplatform/LoomNativePlatformImpl.java <==
/*
 * This file is part of fabric-loom, licensed under the MIT License (MIT).
 *
 * Copyright (c) 2024 FabricMC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.fabricmc.loom.nativeplatform;

class LoomNativePlatformImpl {
	/**
	 * Get the process IDs of the processes holding file handles to the given path.
	 * @param path The path to the file
	 * @return An array of process IDs, may be empty if no processes have open file handles to the given path
	 */
	public static native long[] getPidsHoldingFileHandles(String path);

	/**
	 * Get a list of window titles for the given process ID.
	 * @param pid The process ID
	 * @return An array of window titles, may be empty if the process has no windows
	 */
	public static native String[] getWindowTitlesForPid(long pid);
}

==> fabric-loom-native-0.2.0-sources.jar: net/fabricmc/loom/nativeplatform/LoomNativePlatformImpl.java <==
/*
 * This file is part of fabric-loom, licensed under the MIT License (MIT).
 *
 * Copyright (c) 2024 FabricMC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package net.fabricmc.loom.nativeplatform;

class LoomNativePlatformImpl {
	/**
	 * Get the process IDs of the processes holding file handles to the given path.
	 * @param path The path to the file
	 * @return An array of process IDs, may be empty if no processes have open file handles to the given path
	 */
	public static native long[] getPidsHoldingFileHandles(String path) throws LoomNativePlatformException;

	/**
	 * Get a list of window titles for the given process ID.
	 * @param pid The process ID
	 * @return An array of window titles, may be empty if the process has no windows
	 */
	public static native String[] getWindowTitlesForPid(long pid) throws LoomNativePlatformException;
}
